@@ -1,24 +1,23 @@
 /*
  *    Copyright (C) 1998,1999,2000,2001,2002,2003 Nikos Mavroyanopoulos
  *
- *    This program is free software; you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation; either version 2 of the License, or
- *    (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
- *
- *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *                               
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>. 
  */
 
 /* Some functions that didn't fit elsewhere */
 
-/* $Id: extra.c,v 1.25 2003/02/21 17:57:14 nmav Exp $ */
+/* $Id: extra.c,v 1.2 2007/11/07 17:10:20 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -44,7 +43,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: extra.c,v 1.25 2003/02/21 17:57:14 nmav Exp $";
+    "$Id: extra.c,v 1.2 2007/11/07 17:10:20 nmav Exp $";
 
 #ifndef NO_GETPASS
 	#define FREE_STR(x) \
@@ -366,7 +365,6 @@ int write_file_head(FILE * filedes, char *algorithm, char *mode,
 	buf = mhash_get_hash_name(hash_algorithm);
 	if (buf!=NULL) {
 		strcpy(tmp, buf);
-		free(buf);
 		mcrypt_tolow(tmp, strlen(tmp));
 	} else
 		return 1;
