@@ -1,4 +1,5 @@
-void Bzero( void *s, int n);
+
+/* Bzero is now in libmcrypt */
 
 #ifndef SIGFUNC
 # define SIGFUNC
