@@ -1,25 +1,24 @@
 /*  mcrypt 2.5 - encrypts text or binary files using symmetric algorithms.
  *  For a brief description of the algorithms read the man page.
  *
- *    Copyright (C) 1998,1999,2000,2001,2002 Nikos Mavroyanopoulos
+ *  Copyright (C) 1998,1999,2000,2001,2002,2007 Nikos Mavroyanopoulos
  *
- *    This program is free software; you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation; either version 2 of the License, or
- *    (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
- *
- *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *                               
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>. 
  */
 
 
-/* $Id: mcrypt.c,v 1.36 2002/12/18 11:37:27 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.2 2007/11/07 17:10:21 nmav Exp $ */
 
 #ifndef DEFINES_H
 #define DEFINES_H
@@ -43,7 +42,7 @@
 #endif
 
 static char rcsid[] =
-    "$Id: mcrypt.c,v 1.36 2002/12/18 11:37:27 nmav Exp $";
+    "$Id: mcrypt.c,v 1.2 2007/11/07 17:10:21 nmav Exp $";
 
 char tmperr[128];
 unsigned int stream_flag = FALSE;
@@ -112,7 +111,6 @@ int check_hash_algo(char *chain)
       y = mhash_get_hash_name(i);
       if (y != NULL) {
 	 strcpy(tmp, y);
-	 free(y);
 	 mcrypt_tolow(tmp, strlen(tmp));
 	 if (strcmp(tmp, chain) == 0) {
 	    return i;
@@ -363,7 +361,8 @@ int main(int argc, char **argv)
    }
 
    if (info.mode != NULL) {
-      mode = info.mode;
+      mode = strdup(info.mode);
+      mcrypt_tolow( mode, strlen(mode));
    } else {
       mode = DEFAULT_MODE;
    }
@@ -384,6 +383,8 @@ int main(int argc, char **argv)
       used_algo = TRUE;
       algorithm = _mcrypt_strdup( info.algorithm);
 
+      mcrypt_tolow( algorithm, strlen(algorithm));
+
       i = mcrypt_module_is_block_algorithm(algorithm,
 					   algorithms_directory);
 
