@@ -72,8 +72,10 @@ make_ustring(const uchar *buffer, size_t length)
 {
     USTRING a;
     
-    a = _mcrypt_calloc(1, sizeof *a + length - 1);
+    a = _mcrypt_calloc(1, sizeof *a + length);
     a->len = length;
+    a->d = (void*)a + sizeof *a;
+    memset(a->d, 1, length);
     if (buffer != NULL)
         memcpy(a->d, buffer, length);
     return a;
@@ -88,8 +90,10 @@ realloc_ustring(const USTRING src, size_t length)
     len = length;
     if (src != NULL)
 	len += src->len;
-    a = _mcrypt_calloc(1,  sizeof *a + len - 1);
+    a = _mcrypt_calloc(1,  sizeof *a + len);
     a->len = len;
+    a->d = (void*)a + sizeof *a;
+    memset(a->d, 1, len);
     if (src != NULL) {
 	memcpy(a->d, src->d, src->len);
 	free(src);
@@ -318,7 +322,7 @@ pgp_get_algo(char *algo)
 static uint32
 get_pkt_tag(const uchar *buf, PACKET *pkt)
 {
-    uint32 tag;
+    uint32 tag = -1;
     
     assert(buf);
     if (!(buf[0] & 0x80))
@@ -340,7 +344,7 @@ get_pkt_tag(const uchar *buf, PACKET *pkt)
 static uint32
 length_len(const uint32 len, PACKET *pkt)
 {
-    uint32 ret;
+    uint32 ret = 0;
 
     if (pkt && pkt->blockmode)
         return 1;
@@ -393,7 +397,7 @@ length_encode(uint32 len, uchar *lenbuf, uchar *lensize)
 static uint32
 length_decode(const uchar *buf, int pos, PACKET *pkt)
 {
-    uint32 len;
+    uint32 len = 0;
     
     assert (buf != NULL);
     assert (pos >= 0);
@@ -456,6 +460,8 @@ plaintext_decode(const USTRING pt, USTRING *result)
     PACKET pkt;
     USTRING t;
 
+    memset( &pkt, 0, sizeof(pkt));
+
     assert(pt->len > 0);
     header_decode(pt->d, &tag, &headlen, &offset, &pkt);
     if (tag != PKT_PLAINTEXT)
@@ -475,9 +481,7 @@ plaintext_decode(const USTRING pt, USTRING *result)
     offset++; /* file name length */
     offset += 4; /* timestamp */
 
-    t = _mcrypt_calloc(1,  sizeof *t + pt->len);
-    t->len = pt->len - offset;
-    memcpy(t->d, pt->d + offset, pt->len - offset);
+    t = make_ustring( pt->d+offset, pt->len-offset);
     *result = t;
 
     return PGP_SUCCESS;
@@ -493,7 +497,7 @@ plaintext_encode(const USTRING dat)
     time_t t;
 
     assert(dat->len > 0);
-    result = _mcrypt_calloc(1,  sizeof *result + 2 * dat->len);
+    result = make_ustring( NULL,  2 * dat->len); /* xxx */
     newdat = (USTRING)dat;
     result->d[pos++] = (0x80 | 0x40 | PKT_PLAINTEXT);
 
@@ -662,7 +666,7 @@ symkey_enc_encode(const DEK *dek)
 {
     USTRING result;
     int pos = 0;
-    uchar buf[13];
+    uchar buf[16];
 
     assert(dek->keylen > 0);
 
@@ -695,6 +699,8 @@ read_partial(const uchar *buf, size_t blen, size_t pktlen)
     int pos = 0, partial = 1;
     PACKET pkt;
 
+    memset( &pkt, 0, sizeof(pkt));
+
     dat = make_ustring(NULL, blen);
     while (pktlen > 0) {
         /*fprintf( stderr, "ptklen=%d pos=%d blen=%d partial=%d llen=%d\n",
@@ -732,6 +738,8 @@ encrypted_decode(const DEK *dek, const USTRING dat, USTRING *result)
     uchar rndprefix[18], encprefix[18];
     PACKET pkt;
     USTRING t = NULL, p = NULL;
+
+    memset(&pkt, 0, sizeof(pkt));
     
     assert(dat->len > 0);
     header_decode(dat->d, &tag, &headlen, &offset, &pkt);
@@ -763,9 +771,8 @@ encrypted_decode(const DEK *dek, const USTRING dat, USTRING *result)
     _mcrypt_sync(dek->hd, encprefix, dek->blocklen);
 
     if (!pkt.blockmode) {
-        t = _mcrypt_calloc(1,  sizeof *t + dat->len - offset);
-        t->len = dat->len - offset;
-        memcpy(t->d, dat->d + offset, t->len);
+        t = make_ustring( dat->d+offset,  dat->len - offset); /* xxx */
+
         _mcrypt_decrypt(dek->hd, t->d, t->len, NULL, 0);
     }
     else {
@@ -803,15 +810,14 @@ encrypted_encode(const USTRING pt, const DEK *dek)
     _mcrypt_encrypt(dek->hd, rndpref, dek->blocklen + 2, NULL, 0);
     _mcrypt_sync(dek->hd, rndpref, dek->blocklen);
 
-    ct = _mcrypt_calloc(1,  sizeof *ct + 2 * pt->len);
-    memcpy(ct->d, rndpref, dek->blocklen + 2);
+    ct = make_ustring( rndpref,   2 * pt->len); /* xxx */
     pos = dek->blocklen + 2;
     
     _mcrypt_encrypt(dek->hd, ct->d + pos, pt->len, pt->d, pt->len);
     ct->len = (pos += pt->len);
     pos = 0;
 
-    result = _mcrypt_calloc(1,  sizeof *result + ct->len + 8);
+    result = make_ustring( NULL,  ct->len + 8); /* xxx */
     result->d[pos++] = (0x80 | 0x40 | PKT_ENCRYPTED);
     length_encode(ct->len, lenbuf, &lensize);
     memcpy(result->d + pos, lenbuf, lensize);
@@ -899,7 +905,7 @@ compressed_encode( const USTRING dat, int algo )
     if ( rc )
         goto leave;
 
-    result = _mcrypt_calloc( 1,  sizeof *result + z->len + 8 );
+    result = make_ustring( NULL,  z->len + 8); /* xxx */
     result->len = z->len + 3;
     result->d[0] = (0x80 | 0x40 | PKT_COMPRESSED);
     result->d[1] = 0;
@@ -1083,6 +1089,8 @@ pgp_decrypt_file(const char *infile, const char *outfile, char *pass)
     int rc = 0;
     FILE *fp;
 
+    memset(&pkt, 0, sizeof(pkt));
+
     if (!infile || *infile == '-') {
         while (!feof(stdin)) {
             nread = fread(tmp, 1, DIM (tmp), stdin);
