@@ -63,7 +63,7 @@ enum {
 
 typedef struct ustring_s {
     size_t len;
-    unsigned char d[1];
+    unsigned char *d;
 } *USTRING;
 
 /* Context to hold the data encryption key. */
